checkRequire("Lua_RankBasePanel")
Lua_ArenaRankPanel = class("Lua_ArenaRankPanel", Lua_RankBasePanel)
function Lua_ArenaRankPanel:ctor(p)
	self:superCall("ctor", p, "ArenaRankPanel_skin")
end

function Lua_ArenaRankPanel:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("UPDATE_SINGLE_ARENA_RANK", self, self.updateSingleInfo)

	self.itemList:setListCell(Lua_ArenaRankItem, 688, 125, 1)
	self.myBtnLike:addClickFuntion(self, self.onLikeClick)
end

function Lua_ArenaRankPanel:dispose()
	self:stopTimer()
	self:superCall("dispose")
end

function Lua_ArenaRankPanel:updateSingleInfo(msg)
	for i = 1, self.rankArr:getSize() do
		if self.rankArr[i].player_id == msg.role.player_id then
			self.rankArr[i] = msg.role
			break
		end
	end
	self:updateRankList()
	self:updateLikeTimes(msg.like_num)
end

function Lua_ArenaRankPanel:setData(data)
	self:superCall("setData", data)
	if DataCenter.arenaData.settle_tick > 0 then
		self:startTimer()
		self:onTimer()
	else
		self:stopTimer()
	end
end

function Lua_ArenaRankPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true
		self:addTimer("Lua_ArenaRankPanel", 1, self, self.onTimer)
	end
end

function Lua_ArenaRankPanel:stopTimer()
	if self.bTimer == true then
		self.bTimer = false
		self:removeTimer(self, self.onTimer)
	end
end

function Lua_ArenaRankPanel:onTimer()
	local remainTime = DataCenter.arenaData.settle_tick - DataCenter.roleData.serverTime
	if remainTime > 0 then
		self.timeText:setEnable(true)
		self.timeText.text = LanUtil.formateStr(303031, Lua_TimeTransform.transSeconds1(remainTime))
	else
		self:stopTimer()
		self.timeText:setEnable(false)
	end
end

function Lua_ArenaRankPanel:updateRankInfo(msg)
	if self.bRefresh then
		local len = self.rankArr:getSize()
		local num = len - #msg.rank_list
		while (num > 0) do
			self.rankArr:remove()
			num = num - 1
		end
		for i = 1, #msg.rank_list do
			if i > len then
				self.rankArr:add(msg.rank_list[i])
			else
				self.rankArr[i] = msg.rank_list[i]
			end
		end
	else
		for i = 1, #msg.rank_list do
			self.rankArr:add(msg.rank_list[i])
		end
	end
	self.itemList.isPageEnd = (msg.is_end == 1)
	self:updateRankList()
	self:updateLikeTimes(msg.like_times)

	local info = msg.self_rank
	if info == nil then
		self.myNoneRankSp:setEnable(true)
		self.myNameTxt:setEnable(false)
		self.myLeagueTxt:setEnable(false)
		self.myValueTxt:setEnable(false)
		if self._myRankNum then self._myRankNum:setEnable(false) end
		if self._myAvatarItem then self._myAvatarItem:setEnable(false) end
	else
		if info.rank < 1 then
			self.myNoneRankSp:setEnable(true)
			if self._myRankNum then self._myRankNum:setEnable(false) end
		else
			self.myNoneRankSp:setEnable(false)
			self.myRankNum.num = info.rank
		end
		self.myNameTxt:setEnable(true)
		self.myLeagueTxt:setEnable(true)
		self.myValueTxt:setEnable(true)

		self.myNameTxt.text = info.name
		self.myAvatarItem:setRoleId(info.player_id, nil, info.is_robot)
		self.myAvatarItem:setAvatarBg()
		self.myAvatarItem:setRoleAvatar(info.head_id)
		self.myAvatarItem:setRoleFrame(info.head_frame)
		self.myAvatarItem:setRoleLevel2(info.level)

		self.myValueTxt.text = info.score
		self.myLikeNumTxt.text = info.like_num
		if strIsNullOrEmpty(info.league_name) then
			self.myLeagueTxt:setLangValue(202503)
		else
			self.myLeagueTxt.text = LanUtil.formateStr(202504, info.league_name)
		end
	end
end

function Lua_ArenaRankPanel:updateTopRank()
	local info
	local nameStr
	local leagueStr
	local integralStr
	local btnLikeStr
	local likeNumStr
	local avatarStr
	for i = 1, 3 do
		nameStr = "nameTxt_"..i
		leagueStr = "leagueTxt_"..i
		integralStr = "integralTxt_"..i
		btnLikeStr = "btnLike_"..i
		likeNumStr = "likeNumTxt_"..i
		avatarStr = "avatarItem_"..i
		self[avatarStr]:init()
		self[nameStr]:setLangValue(202500)
		self[leagueStr]:setEnable(false)
		self[integralStr]:setEnable(false)
		self[btnLikeStr]:setEnable(false)
		self[likeNumStr]:setEnable(false)
		info = self.rankArr[i]
		if info then
			self[avatarStr]:setRoleId(info.player_id, nil, info.is_robot)
			self[avatarStr]:setRoleAvatar(info.head_id)
			self[avatarStr]:setRoleFrame(info.head_frame)
			self[avatarStr]:setRoleTitle(info.title)
			self[avatarStr]:setRoleLevel2(info.level)

			self[nameStr].text = info.name

			self[leagueStr]:setEnable(true)
			if strIsNullOrEmpty(info.league_name) then
				self[leagueStr]:setLangValue(202503)
			else
				self[leagueStr].text = info.league_name
			end
			self[integralStr]:setEnable(true)
			self[integralStr].text = info.score

			self[btnLikeStr]:setEnable(true)
			self[btnLikeStr]:addClickFuntion(self, self.onTopLikeClick)
			self[likeNumStr]:setEnable(true)
			self[likeNumStr].text = info.like_num
		end
	end
	self:updateTween()
end

function Lua_ArenaRankPanel:updateLikeTimes(like_times)
	local limitTimes = DataCenter.arenaUtil:getConstConfig("like_limit_times", 1)
	DataCenter.arenaData.likeTimes = like_times
	self.likeNumText.text = LanUtil.formateStr(303013, tostring(like_times), tostring(limitTimes))
end

function Lua_ArenaRankPanel:onTopLikeClick(go)
	local arr = string.split(go.name, "_")
	local key = tonumber(arr[2])
	local data = self.rankArr[key]
	if data == nil then
		return
	end
	if DataCenter.roleData:isMyself(data.player_id) then
		OperateAlert.showLangValue(303030)
		return
	end
	if DataCenter.arenaData.likeTimes <= 0 then
		OperateAlert.showLangValue(303022)
		return
	end
	if data.like_state == 1 then
		OperateAlert.showLangValue(303023)
		return
	end
	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sLikePlayer(data.player_id)
end

function Lua_ArenaRankPanel:onLikeClick(go)
	OperateAlert.showLangValue(303030)
end