checkRequire("Lua_RankBasePanel")
Lua_ChampionshipRankPanel = class("Lua_ChampionshipRankPanel", Lua_RankBasePanel)
function Lua_ChampionshipRankPanel:ctor(p)
	self:superCall("ctor", p, "ArenaRankPanel_skin")
end

function Lua_ChampionshipRankPanel:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("CHAMPIONSHIP_LIKE_UPDATE", self, self.updateSingleInfo)

	self.itemList:setListCell(Lua_ChampionshipRankItem, 688, 125, 1)
	self.timeText:setEnable(false)
	self.myBtnLike:addClickFuntion(self, self.onLikeClick)
end

function Lua_ChampionshipRankPanel:updateSingleInfo(msg)
	for i = 1, self.rankArr:getSize() do
		if self.rankArr[i].id == msg.role_info.id then
			self.rankArr[i] = msg.role_info
			break
		end
	end
	self:updateRankList()
	self:updateTopRank()
	self:updateLikeTimes(msg.left_praise_times)
end

function Lua_ChampionshipRankPanel:updateRankInfo(msg)
	if self.bRefresh then
		local len = self.rankArr:getSize()
		local num = len - #msg.rank_role_list
		while (num > 0) do
			self.rankArr:remove()
			num = num - 1
		end
		for i = 1, #msg.rank_role_list do
			if i > len then
				self.rankArr:add(msg.rank_role_list[i])
			else
				self.rankArr[i] = msg.rank_role_list[i]
			end
		end
	else
		for i = 1, #msg.rank_role_list do
			self.rankArr:add(msg.rank_role_list[i])
		end
	end
	self:updateRankList()
	self:updateLikeTimes(msg.left_praise_times)

	local info = msg.self_rank
	if info == nil then
		self.myNoneRankSp:setEnable(true)
		self.myNameTxt:setEnable(false)
		self.myLeagueTxt:setEnable(false)
		self.myValueTxt:setEnable(false)
		if self._myRankNum then self._myRankNum:setEnable(false) end
		self.myAvatarItem:init()
	else
		if info.rank < 1 then
			self.myNoneRankSp:setEnable(true)
			if self._myRankNum then self._myRankNum:setEnable(false) end
		else
			self.myNoneRankSp:setEnable(false)
			self.myRankNum.num = info.rank
		end
		self.myNameTxt:setEnable(true)
		self.myLeagueTxt:setEnable(true)
		self.myValueTxt:setEnable(true)

		self.myNameTxt.text = info.show_role.name
		self.myAvatarItem:setRoleId(info.id, nil, info.is_robot)
		self.myAvatarItem:setRoleDressUp(info.show_role.dress_info, true)
		self.myAvatarItem:setRoleLevel2(info.show_role.level)

		self.myValueTxt.text = info.score
		self.myLikeNumTxt.text = info.like_num
		if strIsNullOrEmpty(info.show_role.league_name) then
			self.myLeagueTxt:setLangValue(202503)
		else
			self.myLeagueTxt.text = LanUtil.formateStr(202504, info.show_role.league_name)
		end
	end
end

function Lua_ChampionshipRankPanel:updateTopRank()
	local info
	local nameStr
	local leagueStr
	local integralStr
	local btnLikeStr
	local likeNumStr
	local avatarStr
	for i = 1, 3 do
		nameStr = "nameTxt_"..i
		leagueStr = "leagueTxt_"..i
		integralStr = "integralTxt_"..i
		btnLikeStr = "btnLike_"..i
		likeNumStr = "likeNumTxt_"..i
		avatarStr = "avatarItem_"..i
		self[nameStr]:setLangValue(202500)
		self[leagueStr]:setEnable(false)
		self[integralStr]:setEnable(false)
		self[btnLikeStr]:setEnable(false)
		self[likeNumStr]:setEnable(false)
		self[avatarStr]:init()
		info = self.rankArr[i]
		if info then
			self[avatarStr]:setRoleId(info.id, nil, info.is_robot)
			self[avatarStr]:setRoleDressUp(info.show_role.dress_info, true)
			self[avatarStr]:setRoleLevel2(info.show_role.level)

			self[nameStr].text = info.show_role.name

			self[leagueStr]:setEnable(true)
			if strIsNullOrEmpty(info.show_role.league_name) then
				self[leagueStr]:setLangValue(202503)
			else
				self[leagueStr].text = info.show_role.league_name
			end
			self[integralStr]:setEnable(true)
			self[integralStr].text = info.score

			self[btnLikeStr]:setEnable(true)
			self[btnLikeStr]:addClickFuntion(self, self.onTopLikeClick)
			self[likeNumStr]:setEnable(true)
			self[likeNumStr].text = info.like_num
		end
	end
	self:updateTween()
end

function Lua_ChampionshipRankPanel:updateLikeTimes(like_times)
	local limitTimes = DataCenter.championshipUtil.praiseNum
	DataCenter.championshipData.likeTimes = like_times
	self.likeNumText.text = LanUtil.formateStr(540036, tostring(like_times), tostring(limitTimes))
end

function Lua_ChampionshipRankPanel:onTopLikeClick(go)
	local arr = string.split(go.name, "_")
	local key = tonumber(arr[2])
	local data = self.rankArr[key]
	if data == nil then
		return
	end
	if DataCenter.roleData:isMyself(data.id) then
		OperateAlert.showLangValue(540046)
		return
	end
	if DataCenter.championshipData.likeTimes <= 0 then
		OperateAlert.showLangValue(540044)
		return
	end
	if data.is_praised == 1 then
		OperateAlert.showLangValue(540045)
		return
	end
	Lua_ProxyManager.getProxy("Lua_ChampionshipProxy"):sLike(data.id, 2);
end

function Lua_ChampionshipRankPanel:onLikeClick(go)
	OperateAlert.showLangValue(540046)
end