Lua_LeagueDetailWindow = class("Lua_LeagueDetailWindow", Lua_Window)
function Lua_LeagueDetailWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_LeagueDetailWindow"
	self.skinName = "LeagueDetailWindow_skin"
	self.showBlackMask = true
end

function Lua_LeagueDetailWindow:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setLocation(-186, 196, 0)

	self.itemList = Lua_DragList.new(self.content, 628, 450, Lua_AxisDefine.Vertical)
	self.itemList:setListCell(Lua_LeagueDetailItem, 628, 120, 1)
	self.itemList:setLocation(0, -215, 0)
end

function Lua_LeagueDetailWindow:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	if self.itemList then
		self.itemList:dispose()
		self.itemList = nil
	end
	self:superCall("dispose")
end

function Lua_LeagueDetailWindow:showWin(param)
	self:superCall("showWin", param)
	self:updateLeagueInfo(param)
end

function Lua_LeagueDetailWindow:updateLeagueInfo(msg)
	self.avatarItem:setLeagueAvatarId(msg.league.head, 2)

	self.nameText.text = LanUtil.formateStr(202527, msg.league.name)
	self.levelText.text = LanUtil.formateStr(10041, msg.league.level)
	self.numText.text = LanUtil.formateStr(202528, msg.league.id)
	self.forceText.text = LanUtil.formateStr(202529, msg.league.force)
	self.noticeText.text = msg.league.declaration
	self.peopleNumText.text = LanUtil.formateStr(202530, tostring(msg.league.member_amount), tostring(msg.league.max_member))

	table.sort(msg.member_list, function(a, b) 
		return a.show.league_position < b.show.league_position or 
		(a.show.league_position == b.show.league_position and a.online > b.online) end)
	self.itemList:setArrayData(msg.member_list)
end


















Lua_LeagueDetailItem = class("Lua_LeagueDetailItem", Lua_ListCell)
function Lua_LeagueDetailItem:ctor(p)
	self:superCall("ctor", p, "LeagueDetaiItem_skin")
end

function Lua_LeagueDetailItem:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setScale(0.7, 0.7, 0.7)
	self.avatarItem:setLocation(-250, 1.5, 0)
end

function Lua_LeagueDetailItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	self:superCall("dispose")
end

function Lua_LeagueDetailItem:setData(data)
	self.avatarItem:setRoleId(data.show.id, data.show.server_flag)
	self.avatarItem:setRoleDressUp(data.show.dress_info)
	self.avatarItem:setRoleLevel(data.show.level)
	self.nameTxt.text = LanUtil.formateStr(10051, data.show.server_prev, data.show.name)
	self.forceText.text = data.show.force

	self.positionText.text = DataCenter.allianceUtil:getLeagueIdentityByPosition(data.show.league_position)
	if data.show.league_position == 1 then
		self.positionText.colorStr = Lua_ColorDefine.transColor("CB4B24")
	elseif data.show.league_position == 2 then
		self.positionText.colorStr = Lua_ColorDefine.transColor("E48D2F")
	else
		self.positionText.colorStr = Lua_ColorDefine.transColor("795732")
	end

	if data.online == 1 then
		self.stateText:setLangValue(201118)
	else
		local offlineTime = DataCenter.roleData.serverTime - data.offline_tick
		local hour = Mathf.Ceil(offlineTime / 3600)
		if hour < 1 then
			local showTime = Mathf.Ceil(offlineTime / 60)
			self.stateText.text = LanUtil.formateStr(201119, showTime)
		elseif hour < 48 then
			self.stateText.text = LanUtil.formateStr(201120, hour)
		elseif hour < 168 then
			self.stateText.text = LanUtil.formateStr(201121, "2")
		elseif hour >= 168 then
			self.stateText.text = LanUtil.formateStr(201121, "7")
		end
	end
end