Lua_RankEntranceWindow = class("Lua_RankEntranceWindow", Lua_Window)
function Lua_RankEntranceWindow:ctor()
	self:superCall("ctor")

	self.layer = MainWinDefine.MAIN_MENU_TOP_LAYER
	self.windowName = "Lua_RankEntranceWindow"
	self.skinName = "RankEntranceWindow_skin"
	self.isFullSizeWin = true
	self.isFullPaving = true;
end

function Lua_RankEntranceWindow:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("UPDATE_RANK_MAIN_INFO", self, self.updateShowInfo)

	self.itemList = Lua_DragList.new(self.content, 708, 910 + self.adaptHeight, Lua_AxisDefine.Vertical)
	self.itemList:setLocation(0, -145, 0)
	self.itemList.tweenId = 2008
	self.itemList.delayTween = true
	self.itemList:setListCell(Lua_RankEntranceItem, 708, 176, 1)
	self.itemList:setCellSpacing(0, 3)

	local arr = DataCenter.rankUtil:getTabInfo()
	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal)
	self.buttonList:setRectAnchor(7)
	self.buttonList:setLocation(242, 53, 0)
	self.buttonList.pivot = -1
	self.buttonList:setButtonCell(Lua_RankEntranceButtonItem)
	self.buttonList:setButtonLine("common_altas_1", "xui_common_line_001", 2, 114, 0, 0, 1)
	self.buttonList:setButtonItem(118, 118)
	self.buttonList:setClickCallBack(self, self.onButtonClick)
	self.buttonList:setData(arr)
	self.buttonList:setSelected(1)

	Lua_ProxyManager.getProxy("Lua_RankProxy"):sGetRankMainInfo()
end

function Lua_RankEntranceWindow:dispose()
	if self.itemList then
		self.itemList:dispose()
		self.itemList = nil
	end
	if self.buttonList then
		self.buttonList:dispose()
		self.buttonList = nil
	end
	self:superCall("dispose")
end

function Lua_RankEntranceWindow:onScreenResize()
	self:superCall("onScreenResize")
	self.itemList:setContentRect(708, 910 + self.adaptHeight)
end

function Lua_RankEntranceWindow:onButtonClick(index, data)
	local arr = Array()
	local config
	for i = 1, #data.rank_list do
		config = DataCenter.rankUtil:getRankConfig(data.rank_list[i])
		if DataCenter.funcOpenData:isOpened(config.open_cond) then
			arr:add(config.type)
		end
	end
	self.itemList.showTween = true
	self.itemList:setArrayData(arr)
	self.itemList:moveToIndex(1, true)
	self.itemList.canDrag = not self.itemList.isTheEnd
end

function Lua_RankEntranceWindow:updateShowInfo()
	self.itemList:updateShowList()
end




















Lua_RankEntranceButtonItem = class("Lua_RankEntranceButtonItem", Lua_ButtonCell)
function Lua_RankEntranceButtonItem:ctor(p)
	self:superCall("ctor", p)
end

function Lua_RankEntranceButtonItem:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("UPDATE_RANK_REDPOINT", self, self.updateRedPoint)

	self.selectMask = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_zgnbutton_07", 0, 0, 0, 0)
	self.icon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0)
	self.icon.clickScale = false
end

function Lua_RankEntranceButtonItem:dispose()
	if self.redPoint then
		self.redPoint:dispose()
		self.redPoint = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_RankEntranceButtonItem:setData(data)
    self.data = data
    self:updateRedPoint()
end

function Lua_RankEntranceButtonItem:setSelected(index)
	if index == self.index then
		self.icon:setAltas(self.data.textAtlas, self.data.textSelectedSprite)
		self.selectMask:setEnable(true)
	else
		self.icon:setAltas(self.data.textAtlas, self.data.textNormalSprite)
		self.selectMask:setEnable(false)
	end
end

function Lua_RankEntranceButtonItem:setCanClick(bCan)
	if bCan == true then
		self.icon.mouseEnable = true
		self.icon:addClickFuntion(self, self.onPressClick)
	else
		self.icon.mouseEnable = false
		self.icon:removeClickFuntion(self, self.onPressClick)
	end
end

function Lua_RankEntranceButtonItem:updateRedPoint()
	local config
	local state
	for i = 1, #self.data.rank_list do
		config = DataCenter.rankUtil:getRankConfig(self.data.rank_list[i])
		if DataCenter.funcOpenData:isOpened(config.open_cond) then
			state = DataCenter.rankData:getRedPointState(config.type)
			if state == 1 then
				break
			end
		end
	end
	self:showRedPoint(state == 1)
end

function Lua_RankEntranceButtonItem:showRedPoint(value)
	if value == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setLocation(40, 40, 0)
			self.redPoint:createRedPointEff()
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end




















Lua_RankEntranceItem = class("Lua_RankEntranceItem", Lua_ListCell)
function Lua_RankEntranceItem:ctor(p)
	self:superCall("ctor", p, "RankEntranceItem_skin")
end

function Lua_RankEntranceItem:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("UPDATE_RANK_REDPOINT", self, self.updateRedPoint)

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setSiblingIndex(1)
	self.avatarItem:setScale(0.9, 0.9, 1)
	self.avatarItem:setLocation(-258.5, 0, 0)
	self.avatarItem:setAvatarBg("rank_altas", "xui_phb_widget_7")
end

function Lua_RankEntranceItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	if self.redPoint then
		self.redPoint:dispose()
		self.redPoint = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_RankEntranceItem:setData(data)
	self.data = DataCenter.rankUtil:getRankConfig(data)
	self.nameText.text = self.data.title_name
	self.icon:setUrl(self.data.entrance_icon)
	self:updateData()
	self:updateRedPoint()
end

function Lua_RankEntranceItem:updateData()
	self.avatarItem:init()
	self.noneIcon:setEnable(true)
	self.roleText:setLangValue(202500)
	self.desText:setEnable(false)
	self.forceIcon:setEnable(false)
	self.forceText:setEnable(false)

	local info = DataCenter.rankData:getRankMainInfo(self.data.type)
	if info then
		self.noneIcon:setEnable(false)
		if self.data.head_icon_type == 2 then -- 联盟
			self.roleText.text = info.league_show.league_name
			self.avatarItem:setLeagueAvatarId(info.league_show.league_head, 2, 0.5)
		elseif self.data.head_icon_type == 3 then -- 英雄
			self.roleText.text = info.player_show.name
			self.avatarItem:setAvatarBg("common_altas_3", "xui_common_widget_019")
			self.avatarItem:setHeroAvatar(tonumber(info.other_value), nil, info.clothes_id)
		else -- 玩家
			self.roleText.text = info.player_show.name
			self.avatarItem:setRoleDressUp(info.player_show.dress_info, true)
			self.avatarItem:setRoleLevel2(info.player_show.level)
		end

		if self.data.type == Lua_RankData.FIGHT_TYPE then
			self.forceIcon:setEnable(true)
			self.forceText:setEnable(true)
			self.forceText.text = info.player_show.force
		elseif self.data.type == Lua_RankData.MAIN_LINE_TYPE then
			local config1 = Lua_MainLineCheckpointConfigData.getConfig(info.value)
			if config1 then
				local config2 = Lua_MainLineChapterConfigData.getConfig(config1.chapter_id)
				self.desText:setEnable(true)
				self.desText.text = LanUtil.formateStr(10050, self.data.rank_text, config2.name..config1.name)
			end
		elseif self.data.type == Lua_RankData.LEAGUE_TYPE then
			self.forceIcon:setEnable(true)
			self.forceText:setEnable(true)
			self.forceText.text = info.league_show.league_force
		elseif self.data.type == Lua_RankData.STAR_TRIAL_TYPE then
			self.desText:setEnable(true)
			local vo = DataCenter.starTrialUitl:getStageVo(info.sub_value)
			self.desText.text = LanUtil.formateStr(202535, self.data.rank_text, vo.chapter, vo.index, info.value, spliceIconStr("common_altas_1", "xui_common_label_06", 30, 29))
		elseif self.data.type == Lua_RankData.KUNXUHOLYLAND_TYPE then
			self.desText:setEnable(true)
			self.desText.text = LanUtil.formateStr(202534, self.data.rank_text, info.value, info.sub_value, spliceIconStr("common_altas_1", "xui_common_label_06", 30, 29))
		elseif self.data.type >= Lua_RankData.WIND_TYPE and self.data.type <= Lua_RankData.DARK_TYPE  then
			self.forceIcon:setEnable(true)
			self.forceText:setEnable(true)
			self.forceText.text = info.value			
		else
			self.desText:setEnable(true)
			self.desText.text = LanUtil.formateStr(10050, self.data.rank_text, tostring(info.value))
		end
	end
end

function Lua_RankEntranceItem:onPressClick()
	local info = DataCenter.rankData:getRankMainInfo(self.data.type)
	if info then
		local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent)
		if self.avatarItem:checkInBound(winPos.x, winPos.y) then
			if self.data.head_icon_type == 2 then -- 联盟
				Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sOtherAllianceInfo(info.league_show.league_id);		
			else -- 玩家
				Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(info.player_show.id, info.player_show.server_flag);
			end
			return	
		end
	end

	if not DataCenter.funcOpenData:isOpened(self.data.open_cond, true) then
		return
	end
	Lua_WindowUtil.openWin("Lua_RankWindow", Lua_WinParam.ACTION_OPEN, self.data.type)
end

function Lua_RankEntranceItem:updateRedPoint()
	local state = DataCenter.rankData:getRedPointState(self.data.type)
	self:showRedPoint(state == 1)
end

function Lua_RankEntranceItem:showRedPoint(value)
	if value == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setLocation(328, 70, 0)
			self.redPoint:createRedPointEff()
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end