Lua_RankRewardWindow = class("Lua_RankRewardWindow", Lua_Window)
function Lua_RankRewardWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_RankRewardWindow"
	self.skinName = "RankRewardWindow_skin"
	self.showBlackMask = true
	self.isClickClose = true
end

function Lua_RankRewardWindow:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("UPDATE_RANK_REWARD_INFO", self, self.updateData)

	self.itemList = Lua_DragList.new(self.content, 628, 720, Lua_AxisDefine.Vertical)
	self.itemList:setListCell(Lua_RankRewardItem, 628, 165, 1)
	self.itemList:setLocation(0, -60, 0)
end

function Lua_RankRewardWindow:dispose()
	if self.itemList then
		self.itemList:dispose()
		self.itemList = nil
	end
	self:superCall("dispose")
end

function Lua_RankRewardWindow:showWin(param)
	self:superCall("showWin", param)
	Lua_ProxyManager.getProxy("Lua_RankProxy"):sGetRankRewardInfo(param)
end

function Lua_RankRewardWindow:updateData()
	local arr = DataCenter.rankData:getRankRewardArr(self.showData)
	self.itemList:setArrayData(arr)
end























Lua_RankRewardItem = class("Lua_RankRewardItem", Lua_ListCell)
function Lua_RankRewardItem:ctor(p)
	self:superCall("ctor", p, "RankRewardItem_skin")
end

function Lua_RankRewardItem:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content)
	self.avatarItem:setScale(0.7, 0.7, 1)
	self.avatarItem:setLocation(-247.5, -18, 0)

	self.rewardList = Lua_ItemIconList.new(self.content)
	self.rewardList:setLocation(76, -20.5, 0)
	self.rewardList.scaleVal = 0.7

	self.detailTxt:addClickFuntion(self, self.onCheckDetail)
	self.receiveBtn:addClickFuntion(self, self.onReceiveClick)
end

function Lua_RankRewardItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	if self.rewardList then
		self.rewardList:dispose()
		self.rewardList = nil
	end
	if self.redPoint then
		self.redPoint:dispose()
		self.redPoint = nil
	end
	self.data = nil
	self.pass_palyer = nil
	self:superCall("dispose")
end

function Lua_RankRewardItem:setData(data)
	self.data = data
	self.pass_palyer = nil

	self.titleTxt.text = data.title_name
	self.rewardList:setArrayData(data.reward)

	self.avatarItem:init()
	local serverInfo = DataCenter.rankData:getRankProgress(data.id)
	if serverInfo == nil or serverInfo.state == 0 then
		self.noneTxt:setEnable(true)
		self.nameTxt:setEnable(false)
		self.detailTxt:setEnable(false)
		self.avatarItem:setRoleAvatar(0, 1, "rank_altas", "xui_jmd_widget_25")

		self.receiveBtn:setEnable(true)
		self.receiveBtn:setStyle(16)
		self.receiveBtn:setLangValue(202526)
		self.receiveBtn:setMouseEnable(false)
		self.receiveIcon:setEnable(false)
		self:showRedPoint(false)
	else
		self.noneTxt:setEnable(false)
		self.nameTxt:setEnable(true)
		self.detailTxt:setEnable(true)

		self.pass_palyer = serverInfo.pass_palyer
		table.sort(self.pass_palyer, function(a, b) return a.time < b.time end)
		local role = self.pass_palyer[1].player
		self.avatarItem:setRoleId(role.id)
		self.avatarItem:setRoleDressUp(role.dress_info)
		self.avatarItem:setRoleLevel(role.level)
		self.nameTxt.text = role.name

		if serverInfo.state == 1 then
			self.receiveBtn:setEnable(true)
			self.receiveBtn:setStyle(1)
			self.receiveBtn:setLangValue(202505)
			self.receiveBtn:setMouseEnable(true)
			self.receiveIcon:setEnable(false)
		elseif serverInfo.state == 2 then
			self.receiveBtn:setEnable(false)
			self.receiveIcon:setEnable(true)
		end
		self:showRedPoint(serverInfo.state == 1)
	end
end

function Lua_RankRewardItem:onPressClick()
	self.rewardList:onBoundClick()
end

function Lua_RankRewardItem:showRedPoint(value)
	if value == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setLocation(283, -10, 0)
			self.redPoint:createRedPointEff()
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end

function Lua_RankRewardItem:onCheckDetail(go)
	Lua_WindowUtil.openWin("Lua_RankRewardDetailWindow", Lua_WinParam.ACTION_OPEN, self.pass_palyer)
end

function Lua_RankRewardItem:onReceiveClick(go)
	if self.data == nil then
		return
	end
	Lua_ProxyManager.getProxy("Lua_RankProxy"):sReceiveReward(self.data.main_type, self.data.id)
end