checkRequire("Lua_RankItem")
Lua_RankWindow = class("Lua_RankWindow", Lua_Window)
function Lua_RankWindow:ctor()
	self:superCall("ctor")

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_RankWindow"
	self.skinName = "RankWindow_skin"
	self.isFullSizeWin = true
	self.showBlackMask = true
end

function Lua_RankWindow:buildShowItem()
	self:superCall("buildShowItem")
	self.panelDic = {}

	self:addLuaEvent("UPDATE_RANK_INFO", self, self.updateRankInfo)
	self:addLuaEvent("UPDATE_TOWER_RANK_IFNO", self, self.updateRankInfo)
	self:addLuaEvent("UPDATE_LEAGUE_RANK", self, self.updateRankInfo)
	self:addLuaEvent("UPDATE_ARENA_RANK", self, self.updateRankInfo)
	self:addLuaEvent("UPDATE_STARTRIAL_RANK", self, self.updateRankInfo)
	self:addLuaEvent("CHAOSFOREST_RANK_UPDATE", self, self.updateRankInfo)
	self:addLuaEvent("CHAMPIONSHIP_RANK_UPDATE", self, self.updateRankInfo)
	self:addLuaEvent("DIVINEDOMAINTRIAL_RANK_UPDATE", self, self.updateRankInfo)

	self:addLuaEvent("UPDATE_RANK_REDPOINT", self, self.updateRedPoint)

	self.listBg:SetDimensions(720, 563 + self.adaptHeight)
	self.checkReward:addClickFuntion(self, self.onCheckReward)

	self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content)
	self.roleInfoPanel:setRectAnchor(1)

	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal, true, 590, 118)
	self.buttonList:setRectAnchor(7)
	self.buttonList:setRectPivot(5)
	self.buttonList:setLocation(360, 53, 0)
	self.buttonList.clickMoveOffset = 1
	self.buttonList.pivot = -1
	self.buttonList:setButtonCell(Lua_RankButtonItem)
	self.buttonList:setButtonLine("common_altas_1", "xui_common_line_001", 2, 114, 0, 0, 1, 1)
	self.buttonList:setButtonItem(118, 118)
	self.buttonList:setClickCallBack(self, self.onButtonClick)
end

function Lua_RankWindow:dispose()
	if self.panelDic then
		for k, v in pairs(self.panelDic) do
			v:dispose()
			self.panelDic[k] = nil
		end
		self.panelDic = nil
	end
	if self.roleInfoPanel then
		self.roleInfoPanel:dispose()
		self.roleInfoPanel = nil
	end
	if self.buttonList then
		self.buttonList:dispose()
		self.buttonList = nil
	end
	if self.redPoint then
		self.redPoint:dispose()
		self.redPoint = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_RankWindow:onScreenResize()
	self:superCall("onScreenResize")
	self.listBg:SetDimensions(720, 563 + self.adaptHeight)
end

function Lua_RankWindow:showWin(param)
	self:superCall("showWin", param)

	local rankType
	if type(param) == "table" then -- 跳转进入
		rankType = param.main_id
		if rankType == nil then
			OperateAlert.show("打开错误，不存在该排行榜")
			return
		end

		self.data = DataCenter.rankUtil:getRankConfig(rankType)
		if self.data == nil then
			OperateAlert.show("打开错误，不存在该排行榜")
			return
		end

		if rankType >= 4 and rankType <= Lua_RankData.LIGHT_TOWER_TYPE and DataCenter.climbTowerData:checkCampTowerIsOpen() then
			local list = {4, 5, 6, 7, 9}
			local len = #list
			local index
			for i = 1, len do
				if list[i] == rankType then
					index = i
					break
				end
			end
			if len > 4 then
				self.buttonList:setContentRect(590, 118)
			else
				self.buttonList:setContentRect(118 * len, 118)
			end
			self.buttonList:setData(list)
			self.buttonList:moveToIndex(index, true)
			self.buttonList:updateSelected(index)
		end
		self:updateShowInfo()
	else -- 排行榜进入
		rankType = param
		if rankType == nil then
			OperateAlert.show("打开错误，不存在该排行榜")
			return
		end

		self.data = DataCenter.rankUtil:getRankConfig(rankType)
		if self.data == nil then
			OperateAlert.show("打开错误，不存在该排行榜")
			return
		end

		local config = DataCenter.rankUtil:getTabConfig(self.data.belong_id)
		if config and config.rank_list then
			local list = config.rank_list
			local len = #list
			local arr = Array()
			for i = 1, len do
				config = DataCenter.rankUtil:getRankConfig(list[i])
				if DataCenter.funcOpenData:isOpened(config.open_cond) then
					arr:add(config.type)
				end
				if list[i] == rankType then
					index = i
				end
			end
			len = arr:getSize()
			if len > 4 then
				self.buttonList:setContentRect(590, 118)
			else
				self.buttonList:setContentRect(118 * len, 118)
			end
			self.buttonList:setData(arr)
			self.buttonList:moveToIndex(index, true)
			self.buttonList:updateSelected(index)
			self.buttonList.canDrag = not self.buttonList.isTheEnd
		end

		self:updateShowInfo()
	end
end

function Lua_RankWindow:onButtonClick(index, data)
	self.data = DataCenter.rankUtil:getRankConfig(data)
	if not DataCenter.funcOpenData:isOpened(self.data.open_cond, true) then
		self.buttonList:updateSelected(self.selectedIdx)
		return
	end
	self:updateShowInfo()
	self.selectedIdx = index
end

function Lua_RankWindow:updateShowInfo()
	DataCenter.rankData.curRankType = self.data.type

	self.topBg:setUrl(self.data.rank_bg)
	self.nameText.text = self.data.title_name
	if self.data.type == Lua_RankData.CHAOS_FORES_TYPE or self.data.type == Lua_RankData.DIVINEDOMAINTRIAL_TYPE then
		self.checkReward:setEnable(true)
	else
		self.checkReward:setEnable(self.data.has_task == 1)
	end
	self:updateRedPoint()

	for _, v in pairs(self.panelDic) do
		v:setEnable(false)
	end
	if self.panelDic[self.data.show_panel] == nil then
		local showPanel = checkRequire(self.data.show_panel)
		self.panelDic[self.data.show_panel] = showPanel.new(self.content)
		self.panelDic[self.data.show_panel]:setRectAnchor(9)
	end
	self.showPanel = self.panelDic[self.data.show_panel]
	self.showPanel:setEnable(true)
	self.showPanel:onScreenResize(self.adaptHeight)
	self.showPanel:setData(self.data)
end

function Lua_RankWindow:updateRankInfo(msg)
	self.showPanel:updateRankInfo(msg)
end

function Lua_RankWindow:onCheckReward(go)
	if self.data.type == Lua_RankData.CHAOS_FORES_TYPE then
		Lua_WindowUtil.openWin("Lua_ChaosForestRankRewardWindow", Lua_WinParam.ACTION_OPEN)
	elseif self.data.type == Lua_RankData.DIVINEDOMAINTRIAL_TYPE then
		Lua_WindowUtil.openWin("Lua_DivineDomainTrialRankRewardWindow", Lua_WinParam.ACTION_OPEN)
	else
		Lua_WindowUtil.openWin("Lua_RankRewardWindow", Lua_WinParam.ACTION_OPEN, self.data.type)
	end
end

function Lua_RankWindow:updateRedPoint()
	if self.data == nil then
		self:showRedPoint(false)
	else
		local state = DataCenter.rankData:getRedPointState(self.data.type)
		self:showRedPoint(self.data.has_task == 1 and state == 1)
	end
end

function Lua_RankWindow:showRedPoint(value)
	if value == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setRectAnchor(1)
			self.redPoint:setLocation(310, -85, 0)
			self.redPoint:createRedPointEff()
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end



















Lua_RankButtonItem = class("Lua_RankButtonItem", Lua_ButtonCell)
function Lua_RankButtonItem:ctor(p)
	self:superCall("ctor", p)
end

function Lua_RankButtonItem:buildShowItem()
	self:superCall("buildShowItem")
	self:addLuaEvent("UPDATE_RANK_REDPOINT", self, self.updateRedPoint)

	self.selectMask = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_zgnbutton_07", 0, 0, 0, 0)
	self.icon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0)
end

function Lua_RankButtonItem:dispose()
	if self.redPoint then
		self.redPoint:dispose()
		self.redPoint = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_RankButtonItem:setData(data)
    self.data = DataCenter.rankUtil:getRankConfig(data)
    self:updateRedPoint()
end

function Lua_RankButtonItem:setSelected(index)
	if index == self.index then
		self.icon:setAltas(self.data.textAtlas, self.data.textSelectedSprite)
		self.selectMask:setEnable(true)
	else
		self.icon:setAltas(self.data.textAtlas, self.data.textNormalSprite)
		self.selectMask:setEnable(false)
	end
end

function Lua_RankButtonItem:updateRedPoint()
	local state = DataCenter.rankData:getRedPointState(self.data.type)
	self:showRedPoint(state == 1)
end

function Lua_RankButtonItem:showRedPoint(value)
	if value == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setLocation(40, 40, 0)
			self.redPoint:createRedPointEff()
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end